summaryrefslogtreecommitdiff
path: root/player.h
diff options
context:
space:
mode:
authorMike Brady <mikebrady@eircom.net>2018-10-23 10:24:40 +0000
committerMike Brady <mikebrady@eircom.net>2018-10-23 10:26:08 +0000
commit3cb359c747e9ea606e133fac919fe44f7e0896a8 (patch)
tree0efd36babdd5821f8434e55df4998ea58dc1c358 /player.h
parent77176ec4e0b03bbd7ff3fad4c55d5a6c59ec5a1a (diff)
Tighten up integer promotion checks to calculate large delays properly. Fix input rate calculation restarting.
Diffstat (limited to 'player.h')
-rw-r--r--player.h6
1 files changed, 4 insertions, 2 deletions
diff --git a/player.h b/player.h
index a7531b9..2f1a328 100644
--- a/player.h
+++ b/player.h
@@ -218,7 +218,8 @@ typedef struct {
// slightly above or below.
int local_to_remote_time_gradient_sample_count; // the number of samples used to calculate the
// gradient
- uint64_t local_to_remote_time_difference; // used to switch between local and remote clocks
+ // add the following to the local time to get the remote time modulo 2^64
+ uint64_t local_to_remote_time_difference; // used to switch between local and remote clocks
uint64_t local_to_remote_time_difference_measurement_time; // when the above was calculated
int last_stuff_request;
@@ -242,7 +243,8 @@ typedef struct {
void *dapo_private_storage; // this is used for compatibility, if dacp stuff isn't enabled.
} rtsp_conn_info;
-uint32_t rtp_frame_offset(uint32_t from, uint32_t to);
+uint32_t modulo_32_offset(uint32_t from, uint32_t to);
+uint64_t modulo_64_offset(uint64_t from, uint64_t to);
int player_play(rtsp_conn_info *conn);
int player_stop(rtsp_conn_info *conn);